@@ -213,6 +213,10 @@ int main(void) {
                    test_ngtcp2_conn_recv_reset_stream) ||
       !CU_add_test(pSuite, "conn_recv_stop_sending",
                    test_ngtcp2_conn_recv_stop_sending) ||
+      !CU_add_test(pSuite, "conn_recv_stream_data_blocked",
+                   test_ngtcp2_conn_recv_stream_data_blocked) ||
+      !CU_add_test(pSuite, "conn_recv_data_blocked",
+                   test_ngtcp2_conn_recv_data_blocked) ||
       !CU_add_test(pSuite, "conn_recv_conn_id_omitted",
                    test_ngtcp2_conn_recv_conn_id_omitted) ||
       !CU_add_test(pSuite, "conn_short_pkt_type",
@@ -317,6 +321,12 @@ int main(void) {
                    test_ngtcp2_conn_encode_0rtt_transport_params) ||
       !CU_add_test(pSuite, "conn_create_ack_frame",
                    test_ngtcp2_conn_create_ack_frame) ||
+      !CU_add_test(pSuite, "conn_grease_quic_bit",
+                   test_ngtcp2_conn_grease_quic_bit) ||
+      !CU_add_test(pSuite, "conn_send_stream_data_blocked",
+                   test_ngtcp2_conn_send_stream_data_blocked) ||
+      !CU_add_test(pSuite, "conn_send_data_blocked",
+                   test_ngtcp2_conn_send_data_blocked) ||
       !CU_add_test(pSuite, "conn_new_failmalloc",
                    test_ngtcp2_conn_new_failmalloc) ||
       !CU_add_test(pSuite, "accept", test_ngtcp2_accept) ||
